# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/stat_sinks/graphite_statsd/v3/graphite_statsd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/extensions/stat_sinks/graphite_statsd/v3/graphite_statsd.proto\x12.envoy.extensions.stat_sinks.graphite_statsd.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xb6\x01\n\x12GraphiteStatsdSink\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.AddressH\x00\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x45\n\x16max_bytes_per_datagram\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x07\xfa\x42\x04\x32\x02 \x00\x42\x17\n\x10statsd_specifier\x12\x03\xf8\x42\x01\x42\xc6\x01\n<io.envoyproxy.envoy.extensions.stat_sinks.graphite_statsd.v3B\x13GraphiteStatsdProtoP\x01Zggithub.com/envoyproxy/go-control-plane/envoy/extensions/stat_sinks/graphite_statsd/v3;graphite_statsdv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.stat_sinks.graphite_statsd.v3.graphite_statsd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<io.envoyproxy.envoy.extensions.stat_sinks.graphite_statsd.v3B\023GraphiteStatsdProtoP\001Zggithub.com/envoyproxy/go-control-plane/envoy/extensions/stat_sinks/graphite_statsd/v3;graphite_statsdv3\272\200\310\321\006\002\020\002'
  _GRAPHITESTATSDSINK.oneofs_by_name['statsd_specifier']._options = None
  _GRAPHITESTATSDSINK.oneofs_by_name['statsd_specifier']._serialized_options = b'\370B\001'
  _GRAPHITESTATSDSINK.fields_by_name['max_bytes_per_datagram']._options = None
  _GRAPHITESTATSDSINK.fields_by_name['max_bytes_per_datagram']._serialized_options = b'\372B\0042\002 \000'
  _globals['_GRAPHITESTATSDSINK']._serialized_start=245
  _globals['_GRAPHITESTATSDSINK']._serialized_end=427
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/accesslog/v2/accesslog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/config/filter/accesslog/v2/accesslog.proto\x12 envoy.config.filter.accesslog.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a)envoy/api/v2/route/route_components.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x01\n\tAccessLog\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x31.envoy.config.filter.accesslog.v2.AccessLogFilter\x12-\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"\x82\x07\n\x0f\x41\x63\x63\x65ssLogFilter\x12P\n\x12status_code_filter\x18\x01 \x01(\x0b\x32\x32.envoy.config.filter.accesslog.v2.StatusCodeFilterH\x00\x12K\n\x0f\x64uration_filter\x18\x02 \x01(\x0b\x32\x30.envoy.config.filter.accesslog.v2.DurationFilterH\x00\x12Y\n\x17not_health_check_filter\x18\x03 \x01(\x0b\x32\x36.envoy.config.filter.accesslog.v2.NotHealthCheckFilterH\x00\x12M\n\x10traceable_filter\x18\x04 \x01(\x0b\x32\x31.envoy.config.filter.accesslog.v2.TraceableFilterH\x00\x12I\n\x0eruntime_filter\x18\x05 \x01(\x0b\x32/.envoy.config.filter.accesslog.v2.RuntimeFilterH\x00\x12\x41\n\nand_filter\x18\x06 \x01(\x0b\x32+.envoy.config.filter.accesslog.v2.AndFilterH\x00\x12?\n\tor_filter\x18\x07 \x01(\x0b\x32*.envoy.config.filter.accesslog.v2.OrFilterH\x00\x12G\n\rheader_filter\x18\x08 \x01(\x0b\x32..envoy.config.filter.accesslog.v2.HeaderFilterH\x00\x12T\n\x14response_flag_filter\x18\t \x01(\x0b\x32\x34.envoy.config.filter.accesslog.v2.ResponseFlagFilterH\x00\x12P\n\x12grpc_status_filter\x18\n \x01(\x0b\x32\x32.envoy.config.filter.accesslog.v2.GrpcStatusFilterH\x00\x12M\n\x10\x65xtension_filter\x18\x0b \x01(\x0b\x32\x31.envoy.config.filter.accesslog.v2.ExtensionFilterH\x00\x42\x17\n\x10\x66ilter_specifier\x12\x03\xf8\x42\x01\"\xae\x01\n\x10\x43omparisonFilter\x12K\n\x02op\x18\x01 \x01(\x0e\x32\x35.envoy.config.filter.accesslog.v2.ComparisonFilter.OpB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .envoy.api.v2.core.RuntimeUInt32\"\x1c\n\x02Op\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02GE\x10\x01\x12\x06\n\x02LE\x10\x02\"d\n\x10StatusCodeFilter\x12P\n\ncomparison\x18\x01 \x01(\x0b\x32\x32.envoy.config.filter.accesslog.v2.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"b\n\x0e\x44urationFilter\x12P\n\ncomparison\x18\x01 \x01(\x0b\x32\x32.envoy.config.filter.accesslog.v2.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x16\n\x14NotHealthCheckFilter\"\x11\n\x0fTraceableFilter\"\x89\x01\n\rRuntimeFilter\x12\x1c\n\x0bruntime_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x36\n\x0fpercent_sampled\x18\x02 \x01(\x0b\x32\x1d.envoy.type.FractionalPercent\x12\"\n\x1ause_independent_randomness\x18\x03 \x01(\x08\"Y\n\tAndFilter\x12L\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x31.envoy.config.filter.accesslog.v2.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"X\n\x08OrFilter\x12L\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x31.envoy.config.filter.accesslog.v2.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"K\n\x0cHeaderFilter\x12;\n\x06header\x18\x01 \x01(\x0b\x32!.envoy.api.v2.route.HeaderMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x81\x01\n\x12ResponseFlagFilter\x12k\n\x05\x66lags\x18\x01 \x03(\tB\\\xfa\x42Y\x92\x01V\"TrRR\x02LHR\x02UHR\x02UTR\x02LRR\x02URR\x02UFR\x02UCR\x02UOR\x02NRR\x02\x44IR\x02\x46IR\x02RLR\x04UAEXR\x04RLSER\x02\x44\x43R\x03URXR\x02SIR\x02IHR\x03\x44PE\"\xba\x03\n\x10GrpcStatusFilter\x12Z\n\x08statuses\x18\x01 \x03(\x0e\x32\x39.envoy.config.filter.accesslog.v2.GrpcStatusFilter.StatusB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xb8\x02\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x13\n\x0fUNAUTHENTICATED\x10\x10\"\x8b\x01\n\x0f\x45xtensionFilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_typeB\xc0\x01\n.io.envoyproxy.envoy.config.filter.accesslog.v2B\x0e\x41\x63\x63\x65sslogProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/config/filter/accesslog/v2;accesslogv2\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.config.accesslog.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.accesslog.v2.accesslog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.envoyproxy.envoy.config.filter.accesslog.v2B\016AccesslogProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/config/filter/accesslog/v2;accesslogv2\362\230\376\217\005\033\022\031envoy.config.accesslog.v3\272\200\310\321\006\002\020\001'
  _ACCESSLOG.fields_by_name['config']._options = None
  _ACCESSLOG.fields_by_name['config']._serialized_options = b'\030\001'
  _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._options = None
  _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._serialized_options = b'\370B\001'
  _COMPARISONFILTER.fields_by_name['op']._options = None
  _COMPARISONFILTER.fields_by_name['op']._serialized_options = b'\372B\005\202\001\002\020\001'
  _STATUSCODEFILTER.fields_by_name['comparison']._options = None
  _STATUSCODEFILTER.fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DURATIONFILTER.fields_by_name['comparison']._options = None
  _DURATIONFILTER.fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RUNTIMEFILTER.fields_by_name['runtime_key']._options = None
  _RUNTIMEFILTER.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002 \001'
  _ANDFILTER.fields_by_name['filters']._options = None
  _ANDFILTER.fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _ORFILTER.fields_by_name['filters']._options = None
  _ORFILTER.fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _HEADERFILTER.fields_by_name['header']._options = None
  _HEADERFILTER.fields_by_name['header']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RESPONSEFLAGFILTER.fields_by_name['flags']._options = None
  _RESPONSEFLAGFILTER.fields_by_name['flags']._serialized_options = b'\372BY\222\001V\"TrRR\002LHR\002UHR\002UTR\002LRR\002URR\002UFR\002UCR\002UOR\002NRR\002DIR\002FIR\002RLR\004UAEXR\004RLSER\002DCR\003URXR\002SIR\002IHR\003DPE'
  _GRPCSTATUSFILTER.fields_by_name['statuses']._options = None
  _GRPCSTATUSFILTER.fields_by_name['statuses']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _EXTENSIONFILTER.fields_by_name['config']._options = None
  _EXTENSIONFILTER.fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_ACCESSLOG']._serialized_start=331
  _globals['_ACCESSLOG']._serialized_end=531
  _globals['_ACCESSLOGFILTER']._serialized_start=534
  _globals['_ACCESSLOGFILTER']._serialized_end=1432
  _globals['_COMPARISONFILTER']._serialized_start=1435
  _globals['_COMPARISONFILTER']._serialized_end=1609
  _globals['_COMPARISONFILTER_OP']._serialized_start=1581
  _globals['_COMPARISONFILTER_OP']._serialized_end=1609
  _globals['_STATUSCODEFILTER']._serialized_start=1611
  _globals['_STATUSCODEFILTER']._serialized_end=1711
  _globals['_DURATIONFILTER']._serialized_start=1713
  _globals['_DURATIONFILTER']._serialized_end=1811
  _globals['_NOTHEALTHCHECKFILTER']._serialized_start=1813
  _globals['_NOTHEALTHCHECKFILTER']._serialized_end=1835
  _globals['_TRACEABLEFILTER']._serialized_start=1837
  _globals['_TRACEABLEFILTER']._serialized_end=1854
  _globals['_RUNTIMEFILTER']._serialized_start=1857
  _globals['_RUNTIMEFILTER']._serialized_end=1994
  _globals['_ANDFILTER']._serialized_start=1996
  _globals['_ANDFILTER']._serialized_end=2085
  _globals['_ORFILTER']._serialized_start=2087
  _globals['_ORFILTER']._serialized_end=2175
  _globals['_HEADERFILTER']._serialized_start=2177
  _globals['_HEADERFILTER']._serialized_end=2252
  _globals['_RESPONSEFLAGFILTER']._serialized_start=2255
  _globals['_RESPONSEFLAGFILTER']._serialized_end=2384
  _globals['_GRPCSTATUSFILTER']._serialized_start=2387
  _globals['_GRPCSTATUSFILTER']._serialized_end=2829
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_start=2517
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_end=2829
  _globals['_EXTENSIONFILTER']._serialized_start=2832
  _globals['_EXTENSIONFILTER']._serialized_end=2971
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65nvoy/api/v2/discovery.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x17google/rpc/status.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xbb\x01\n\x10\x44iscoveryRequest\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12%\n\x04node\x18\x02 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12\x16\n\x0eresource_names\x18\x03 \x03(\t\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x16\n\x0eresponse_nonce\x18\x05 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x06 \x01(\x0b\x32\x12.google.rpc.Status\"\xbb\x01\n\x11\x44iscoveryResponse\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12\'\n\tresources\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06\x63\x61nary\x18\x03 \x01(\x08\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x36\n\rcontrol_plane\x18\x06 \x01(\x0b\x32\x1f.envoy.api.v2.core.ControlPlane\"\xfd\x02\n\x15\x44\x65ltaDiscoveryRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12\x10\n\x08type_url\x18\x02 \x01(\t\x12 \n\x18resource_names_subscribe\x18\x03 \x03(\t\x12\"\n\x1aresource_names_unsubscribe\x18\x04 \x03(\t\x12\x63\n\x19initial_resource_versions\x18\x05 \x03(\x0b\x32@.envoy.api.v2.DeltaDiscoveryRequest.InitialResourceVersionsEntry\x12\x16\n\x0eresponse_nonce\x18\x06 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x07 \x01(\x0b\x32\x12.google.rpc.Status\x1a>\n\x1cInitialResourceVersionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x16\x44\x65ltaDiscoveryResponse\x12\x1b\n\x13system_version_info\x18\x01 \x01(\t\x12)\n\tresources\x18\x02 \x03(\x0b\x32\x16.envoy.api.v2.Resource\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x19\n\x11removed_resources\x18\x06 \x03(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\"b\n\x08Resource\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x61liases\x18\x04 \x03(\t\x12\x0f\n\x07version\x18\x01 \x01(\t\x12&\n\x08resource\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x93\x01\n\x1aio.envoyproxy.envoy.api.v2B\x0e\x44iscoveryProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1c\x12\x1a\x65nvoy.service.discovery.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.discovery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\016DiscoveryProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\034\022\032envoy.service.discovery.v3\272\200\310\321\006\002\020\001'
  _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY._options = None
  _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY._serialized_options = b'8\001'
  _globals['_DISCOVERYREQUEST']._serialized_start=192
  _globals['_DISCOVERYREQUEST']._serialized_end=379
  _globals['_DISCOVERYRESPONSE']._serialized_start=382
  _globals['_DISCOVERYRESPONSE']._serialized_end=569
  _globals['_DELTADISCOVERYREQUEST']._serialized_start=572
  _globals['_DELTADISCOVERYREQUEST']._serialized_end=953
  _globals['_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY']._serialized_start=891
  _globals['_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY']._serialized_end=953
  _globals['_DELTADISCOVERYRESPONSE']._serialized_start=956
  _globals['_DELTADISCOVERYRESPONSE']._serialized_end=1112
  _globals['_RESOURCE']._serialized_start=1114
  _globals['_RESOURCE']._serialized_end=1212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/eval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import value_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_value__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#google/api/expr/v1alpha1/eval.proto\x12\x18google.api.expr.v1alpha1\x1a$google/api/expr/v1alpha1/value.proto\x1a\x17google/rpc/status.proto\"\xa4\x01\n\tEvalState\x12\x33\n\x06values\x18\x01 \x03(\x0b\x32#.google.api.expr.v1alpha1.ExprValue\x12;\n\x07results\x18\x03 \x03(\x0b\x32*.google.api.expr.v1alpha1.EvalState.Result\x1a%\n\x06Result\x12\x0c\n\x04\x65xpr\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03\"\xb3\x01\n\tExprValue\x12\x30\n\x05value\x18\x01 \x01(\x0b\x32\x1f.google.api.expr.v1alpha1.ValueH\x00\x12\x33\n\x05\x65rror\x18\x02 \x01(\x0b\x32\".google.api.expr.v1alpha1.ErrorSetH\x00\x12\x37\n\x07unknown\x18\x03 \x01(\x0b\x32$.google.api.expr.v1alpha1.UnknownSetH\x00\x42\x06\n\x04kind\".\n\x08\x45rrorSet\x12\"\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x12.google.rpc.Status\"\x1b\n\nUnknownSet\x12\r\n\x05\x65xprs\x18\x01 \x03(\x03\x42l\n\x1c\x63om.google.api.expr.v1alpha1B\tEvalProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.eval_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\tEvalProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001'
  _globals['_EVALSTATE']._serialized_start=129
  _globals['_EVALSTATE']._serialized_end=293
  _globals['_EVALSTATE_RESULT']._serialized_start=256
  _globals['_EVALSTATE_RESULT']._serialized_end=293
  _globals['_EXPRVALUE']._serialized_start=296
  _globals['_EXPRVALUE']._serialized_end=475
  _globals['_ERRORSET']._serialized_start=477
  _globals['_ERRORSET']._serialized_end=523
  _globals['_UNKNOWNSET']._serialized_start=525
  _globals['_UNKNOWNSET']._serialized_end=552
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.extensions.transport_sockets.tls.v3 import common_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6envoy/extensions/transport_sockets/tls/v3/secret.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/common.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"q\n\rGenericSecret\x12\x38\n\x06secret\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.auth.GenericSecret\"\x8a\x01\n\x0fSdsSecretConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x36\n\nsds_config\x18\x02 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSource:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.auth.SdsSecretConfig\"\xb0\x03\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12T\n\x0ftls_certificate\x18\x02 \x01(\x0b\x32\x39.envoy.extensions.transport_sockets.tls.v3.TlsCertificateH\x00\x12^\n\x13session_ticket_keys\x18\x03 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeysH\x00\x12\x65\n\x12validation_context\x18\x04 \x01(\x0b\x32G.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContextH\x00\x12R\n\x0egeneric_secret\x18\x05 \x01(\x0b\x32\x38.envoy.extensions.transport_sockets.tls.v3.GenericSecretH\x00:\x1f\x9a\xc5\x88\x1e\x1a\n\x18\x65nvoy.api.v2.auth.SecretB\x06\n\x04typeB\xa8\x01\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\x0bSecretProtoP\x01ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tls.v3.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\013SecretProtoP\001ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\272\200\310\321\006\002\020\002'
  _GENERICSECRET.fields_by_name['secret']._options = None
  _GENERICSECRET.fields_by_name['secret']._serialized_options = b'\270\267\213\244\002\001'
  _GENERICSECRET._options = None
  _GENERICSECRET._serialized_options = b'\232\305\210\036!\n\037envoy.api.v2.auth.GenericSecret'
  _SDSSECRETCONFIG.fields_by_name['name']._options = None
  _SDSSECRETCONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _SDSSECRETCONFIG._options = None
  _SDSSECRETCONFIG._serialized_options = b'\232\305\210\036#\n!envoy.api.v2.auth.SdsSecretConfig'
  _SECRET._options = None
  _SECRET._serialized_options = b'\232\305\210\036\032\n\030envoy.api.v2.auth.Secret'
  _globals['_GENERICSECRET']._serialized_start=357
  _globals['_GENERICSECRET']._serialized_end=470
  _globals['_SDSSECRETCONFIG']._serialized_start=473
  _globals['_SDSSECRETCONFIG']._serialized_end=611
  _globals['_SECRET']._serialized_start=614
  _globals['_SECRET']._serialized_end=1046
# @@protoc_insertion_point(module_scope)
